@@ -109,7 +109,7 @@ def run(args):
     include_path_match = IncludePathsMatch()
     include_name_match = IncludeNameMatch()
 
-    return launch_behavex(args_parsed)
+    return launch_behavex()
 
 
 def setup_running_failures(args_parsed):
@@ -136,7 +136,7 @@ def init_multiprocessing():
     signal.signal(signal.SIGINT, signal.SIG_IGN)
 
 
-def launch_behavex(args):
+def launch_behavex():
     """Launch the BehaveX test execution in the specified parallel mode."""
     json_reports = None
     execution_codes = None
@@ -176,10 +176,8 @@ def launch_behavex(args):
             )
 
         customized_json = get_param('customized_json')
-        print(customized_json)
-        print(args.customized_json)
 
-        if args.customized_json == '':
+        if bool(customized_json) is not True and str(customized_json) != 'True':
             with open(customized_json, 'r') as f:
                 json_reports = json.load(f)
 
